#
# Recipe:: ds_opencv
#
# Copyright (c) 2017 The Dark Sky Company, LLC, All Rights Reserved.

# include_recipe 'apt'
# include_recipe 'build-essential'
apt_update
build_essential
include_recipe 'git'

# What apt packages to install based on OpenCV major version
packages = {
  '2' => %w(
    cmake
    libgtk2.0-dev
    pkg-config
    libavcodec-dev
    libavformat-dev
    libswscale-dev
    python-dev
    python-numpy
  ),
  '3' => %w(
    cmake
    gfortran
    libjpeg8-dev
    libtiff5-dev
    libpng-dev
    libatlas-base-dev
  ),
  '4' => %w(
    cmake
    gcc
    g++
    python3-dev
    python3-numpy
    libavcodec-dev
    libavformat-dev
    libswscale-dev
  ),
}

opencv_major_version = node['ds_opencv']['opencv']['version'][0]

packages[opencv_major_version].each do |pkg|
  package pkg
end

opencv_path = node['ds_opencv']['opencv']['path']

git opencv_path do
  repository 'https://github.com/opencv/opencv.git'
  revision   node['ds_opencv']['opencv']['version']
  action     :checkout
end

directory "#{opencv_path}/release"

cmake_define = node['ds_opencv']['opencv']['cmake_define']
               .map { |k, v| "-D #{k}=#{v}" }.join(' ')

execute 'cmake_opencv' do
  command "cmake #{cmake_define} .."
  cwd     "#{opencv_path}/release"
  creates "#{opencv_path}/release/Makefile"
end

execute 'make_opencv' do
  command 'make -j4 && make install && ldconfig'
  cwd     "#{opencv_path}/release"
  creates node['ds_opencv']['opencv']['cmake_define']['MAKE_INSTALL_PREFIX'] +
          "/lib/libopencv_core.so.#{node['ds_opencv']['opencv']['version']}"
end
